==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/cl/iclcontrolscript.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iclcontrolscript.h"


#include "ihelpfactory.h"
#include "istring.h"

#include <vtkIOStream.h>

#include <stdio.h>

//
//  macros
//
#include "ibasescriptmacro.h"


#ifndef IFRIT_NO_CONSOLEIO
#ifdef _WIN32
#include <conio.h>
#define getch() _getch()
#else
#include <curses.h>
#endif
#endif


#define curScript		iPointerCast<iclControlScript,iScript>(me)


iclControlScript::iclControlScript(iControlModule *cm, iScript *parent) : iControlScript(cm,parent)
{
}


iclControlScript::~iclControlScript()
{
}

//
//  Own console functions
//
void iclControlScript::OutputText(const iString &s0)
{
	//
	//  Help is kept in HTML format. Strip formatting first.
	//
	iString s(s0);
	s.ReformatHTMLToText(78);

	//
	//  Use paging (a-la 'more')
	//
	int ioff = 0;
	iString tmp;
	tmp = s.Section("\n",ioff,ioff+19);
	while(!tmp.IsEmpty())
	{
		cout << tmp.ToCharPointer() << endl;
		ioff += 20;
		tmp = s.Section("\n",ioff,ioff+19);
		if(!tmp.IsEmpty())
		{
			cout << "Press <Enter> to continue...";
			cout.flush();
#ifndef IFRIT_NO_CONSOLEIO
			getch();
			cout << "\r                            \r";
#else
			getchar();
#endif
		}
	}
}

void iclControlScript::OutputError(const iString &s0)
{
	//
	//  Help is kept in HTML format. Strip formatting first.
	//
	iString s(s0);
	s.ReformatHTMLToText(70);

	//
	//  Send to cerr
	//
	cerr << "ERROR: " << s.ToCharPointer() << endl;
}


//
//  This is whether the actual help text lives
//
const iString& iclControlScript::GetHelpString(_HelpId id) const
{
	static const iString s0 = iControlScript::GetHelpString(_Root) + 
		 "<blockquote>"
		 "    <code><b>window</b></code><br></blockquote>"
		 "activates mouse interaction in the current visualization window; press <code>q</code> in the visualization window to switch back to shell. You can also use a single dot (.) as a shortcut to this command.<br>";

	if(id == _Root) return s0; else return iControlScript::GetHelpString(id);
}

==> ifrit_3.1.5.orig.tar.gz: ifrit-3.1.5/shells/cl/iclcontrolscript.cpp <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#include "iclcontrolscript.h"


#include "ihelpfactory.h"
#include "istring.h"

#include <vtkIOStream.h>

#include <stdio.h>

//
//  macros
//
#include "ibasescriptmacro.h"


#ifndef I_NO_CONSOLEIO
#ifdef _WIN32
#include <conio.h>
#define getch() _getch()
#else
#include <curses.h>
#endif
#endif


#define curScript	iRequiredCast<iclControlScript>(INFO,me)


iclControlScript::iclControlScript(iControlModule *cm, iScript *parent) : iControlScript(cm,parent)
{
}


iclControlScript::~iclControlScript()
{
}

//
//  Own console functions
//
void iclControlScript::OutputText(const iString &s0)
{
	//
	//  Help is kept in HTML format. Strip formatting first.
	//
	iString s(s0);
	s.ReformatHTMLToText(78);

	//
	//  Use paging (a-la 'more')
	//
	int ioff = 0;
	iString tmp;
	tmp = s.Section("\n",ioff,ioff+19);
	while(!tmp.IsEmpty())
	{
		cout << tmp.ToCharPointer() << endl;
		ioff += 20;
		tmp = s.Section("\n",ioff,ioff+19);
		if(!tmp.IsEmpty())
		{
			cout << "Press <Enter> to continue...";
			cout.flush();
#ifndef I_NO_CONSOLEIO
			getch();
			cout << "\r                            \r";
#else
			getchar();
#endif
		}
	}
}

void iclControlScript::OutputError(const iString &s0)
{
	//
	//  Help is kept in HTML format. Strip formatting first.
	//
	iString s(s0);
	s.ReformatHTMLToText(70);

	//
	//  Send to cerr
	//
	cerr << "ERROR: " << s.ToCharPointer() << endl;
}


//
//  This is whether the actual help text lives
//
const iString& iclControlScript::GetHelpString(_HelpId id) const
{
	static const iString s0 = iControlScript::GetHelpString(_Root) + 
		 "<blockquote>"
		 "    <code><b>window</b></code><br></blockquote>"
		 "activates mouse interaction in the current visualization window; press <code>q</code> in the visualization window to switch back to shell. You can also use a single dot (.) as a shortcut to this command.<br>";

	if(id == _Root) return s0; else return iControlScript::GetHelpString(id);
}
